==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/TRANSFERFEESFORSTOREGROUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TRANSFERFEESFORSTOREGROUPID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TRANSFERFEESFORSTOREGROUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMSTOREGROUP"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOSTOREGROUP"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TRANSFERFEESFORSTOREGROUPID_Type", propOrder = {
    "fromstoregroup",
    "classid",
    "tostoregroup"
})
public class TRANSFERFEESFORSTOREGROUPID_Type {

    @XmlElement(name = "FROMSTOREGROUP", required = true)
    protected STOREGROUPID_Type fromstoregroup;
    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "TOSTOREGROUP", required = true)
    protected STOREGROUPID_Type tostoregroup;

    /**
     * Obtient la valeur de la propriété fromstoregroup.
     * 
     * @return
     *     possible object is
     *     {@link STOREGROUPID_Type }
     *     
     */
    public STOREGROUPID_Type getFROMSTOREGROUP() {
        return fromstoregroup;
    }

    /**
     * Définit la valeur de la propriété fromstoregroup.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREGROUPID_Type }
     *     
     */
    public void setFROMSTOREGROUP(STOREGROUPID_Type value) {
        this.fromstoregroup = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété tostoregroup.
     * 
     * @return
     *     possible object is
     *     {@link STOREGROUPID_Type }
     *     
     */
    public STOREGROUPID_Type getTOSTOREGROUP() {
        return tostoregroup;
    }

    /**
     * Définit la valeur de la propriété tostoregroup.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREGROUPID_Type }
     *     
     */
    public void setTOSTOREGROUP(STOREGROUPID_Type value) {
        this.tostoregroup = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/TRANSFERFEESFORSTOREGROUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TRANSFERFEESFORSTOREGROUPID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TRANSFERFEESFORSTOREGROUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMSTOREGROUP"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOSTOREGROUP"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TRANSFERFEESFORSTOREGROUPID_Type", propOrder = {
    "fromstoregroup",
    "classid",
    "tostoregroup"
})
public class TRANSFERFEESFORSTOREGROUPID_Type {

    @XmlElement(name = "FROMSTOREGROUP", required = true)
    protected STOREGROUPID_Type fromstoregroup;
    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "TOSTOREGROUP", required = true)
    protected STOREGROUPID_Type tostoregroup;

    /**
     * Gets the value of the fromstoregroup property.
     * 
     * @return
     *     possible object is
     *     {@link STOREGROUPID_Type }
     *     
     */
    public STOREGROUPID_Type getFROMSTOREGROUP() {
        return fromstoregroup;
    }

    /**
     * Sets the value of the fromstoregroup property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREGROUPID_Type }
     *     
     */
    public void setFROMSTOREGROUP(STOREGROUPID_Type value) {
        this.fromstoregroup = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the tostoregroup property.
     * 
     * @return
     *     possible object is
     *     {@link STOREGROUPID_Type }
     *     
     */
    public STOREGROUPID_Type getTOSTOREGROUP() {
        return tostoregroup;
    }

    /**
     * Sets the value of the tostoregroup property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREGROUPID_Type }
     *     
     */
    public void setTOSTOREGROUP(STOREGROUPID_Type value) {
        this.tostoregroup = value;
    }

}
